**Get started installing requirments**


You must start off by cloning the repository. install **python** and **pip**:

1. Install the requirements:

pip install -r requirements.txt 

2. Initilise a new database:

python manage.py migrate

3. Start the server:

python manage.py runserver

Access the server at *http://localhost:8000/.*

 
**How to use the virtual environment**


1. in this part you will need to create the environment:

python -m venve env/

2. in a git bash terminal, start up the virtual environment:

source env/script/activate

3. install requirements and start up the server:

pip install -r requirements.txt
python manage runserver


**Setting up Django**

1. to initialise the Database and update it, run:

python manage.py migrate

2. to make new migrations and update the database, run:

python manage.py makemigrations <app-name>


**Accessing the admin panel**


if you want to access the admin panel, you need a super user account:

python manage.py createsuperuser


*after all this you must navigate to localhost:8000/admin/ and log in with the account you just created.*


**Running the tests**

python manage.py test


***Technical Overview***
1. Build and Deployment Pipeline
The project follows a Continuous Integration and Continuous Delivery (CI/CD) pipeline to ensure smooth development, testing, and deployment. The build pipeline is triggered upon push events to the repository, where it:

* Runs automated tests to ensure the integrity of the application.
* Deploys the application to staging for further testing.
* Deploys the application to production after successful staging tests.

2. Continuous Integration and Continuous Delivery Tools
We use GitLab CI/CD for continuous integration and delivery. The pipeline automates the following steps:

* Code linting and static analysis.
* Unit testing for the backend (Django) and frontend (JavaScript).
* Deployment to staging and production environments.
* GitLab’s built-in CI/CD features ensure smooth automation from code commits to deployment, allowing fast iteration and feedback.

3. Third-Party Services and APIs
The project integrates with several third-party services:

* Cloud Hosting: The application will be deployed on Azure for cloud hosting, providing scalability and reliability.
* Authentication: We use Auth for user authentication, allowing smooth integration with third-party login services (Google, Facebook, etc.).
* Email Service: The platform has an email service (like SendGrid or Amazon SES) to send notifications to users about updates or changes.

4. Coding Style, Development and Coding Conventions
We follow the standard coding practices to ensure clean, maintainable, and readable code. The following conventions are followed:

* Python: We use PEP 8 for Python code style, ensuring consistency and readability.
* JavaScript: The JavaScript code follows the Airbnb JavaScript Style Guide, with strict rules for indentation, naming conventions, and code formatting.
* HTML/CSS: We follow W3C standards for HTML and CSS best practices for responsive design.

5. Software Architecture
The software follows a Model-View-Template (MVT) architecture pattern, which is the Django equivalent of MVC. Key components include:

* Model: The data layer, responsible for defining the structure of the database and business logic.
* View: Handles the logic to process user requests and return appropriate responses.
* Template: Defines the presentation layer using Django templates to render HTML content dynamically.
The frontend is built using HTML, CSS, and JavaScript, with Django serving the backend. APIs may be used to fetch additional data where necessary.

6. Non-Standard Development Tools and Approaches
While most of the tools used are common in web development, the following tools or approaches may be considered non-standard:

* Django REST Framework (DRF): For building and consuming APIs in the backend, facilitating communication between frontend and backend.
* Webpack: For bundling JavaScript files and assets in an optimized manner for production.
* Docker: We may use Docker for containerizing the application during development or deployment, ensuring consistent environments across different stages.

7. Software Licenses
The project is licensed under the MIT License. This allows anyone to freely use, modify, and distribute the codebase, with the condition that the original license and copyright notice are included in all copies or substantial portions of the software.


If in any more support, take a look at this website:
https://learndjango.com/courses/django-for-beginners/chapter-2-hello-world-website/